#include "jDockApp/jDockApp.h"
#include "jDockApp/colors.h"
#include <getopt.h>

void show_help(char *s) {
    printf("Usage: %s <-s<text>> [-d<#> -n<#> -p<#.#> -c<#.#> -B[#.#] -S<#.#>]\n\n", s);
    printf("-d      <delay>: Seconds between executions of stockchk [500s].\n");
    printf("-s     <symbol>: Symbol to look up.\n");
    printf("-n     <shares>: Number of shares owned.\n");
    printf("-p      <price>: Purchase price (no fractions).\n");
    printf("-c <commission>: Total broker commission.\n\n");
    //printf("-B      [price]: Purchase execution price.\n");
    //printf("-S      <price>: Selling execution price.\n\n");

    exit(0);
}

char  symbol[10];
char command[20];

int   shares     = 0;
float price      = 0;
float commission = 0;

float b_price    = -1;
float s_price    = 10000.0;

void setup(int argc, char** argv) {
    char c;
    int  i=0, must=0;
    while( -1 != (c = getopt(argc, argv, "d:s:p:c:n:B::S:"))) {
        switch(c) {
            case '?': exit(1);
            case 'h': show_help(argv[0]);

            case 's': 
                strcpy(symbol, optarg); 
                sprintf(command, "stockchk %s", symbol);
                must=1; 
                break;

            case 'd':      i = atoi(optarg); break;
            case 'n': shares = atoi(optarg); break;

            case 'p': price      = atof(optarg); break;
            case 'c': commission = atof(optarg); break;

            //case 'S': s_price    = atof(optarg); break;

            //case 'B': b_price = (optarg) ? atof(optarg) : -100; break;
        }
    }

    b_price = (b_price == -100) ? price : b_price;

    if(!must) {
        printf("You need to specify at a symbol.\n\n");
        show_help(argv[0]);
    }
    set_update_delay((i) ? i : 500); /* seconds */
    set_loop_delay(1000);            /* mu seconds */
}

float profit(float last) {
    float orig    = (shares*price);
    float current =  shares*last;

    return (current - orig) - commission;
}

void do_update() {
    int i; 
    long   vol;
    double voll;
    float last;
    char letter;
    float prof;
    float high;
    float low;

    FILE *f = popen(command, "r");
    fscanf(f, "%f - %i", &last, &vol);
    fscanf(f, "%f - %f", &low, &high);
    pclose(f);

    clear_window();

    jpprintf(0, 0, YELLOW, "    J-Stock");

    jpprintf(0, 1, BLUE, "Sym:");
    jpprintf(4, 1, CYAN, "%s", symbol);

    jpprintf(0, 2, BLUE, "lst:");
    jpprintf(4, 2, PINK, "%.2f", last);

    if(vol > 1000 && vol < 10000) {
        voll = vol/1000.0;
        letter = 'k';
    } else if (vol > 10000) {
        voll = vol/1000000.0;
        letter = 'M';
    }

    jpprintf(0, 3, BLUE, "vol:");
    jpprintf(4, 3, PINK, "%.1f", voll);
    jprintf(VIOLET, "%c", letter);

    if(b_price >= low) {
        jpprintf(2, 4, RED, "<bought>");
    }

    if(s_price <= high) {
        jpprintf(2, 4, RED, "<sold>");
    }

    if(shares) {
        prof = profit(last);
        jpprintf(0,5, BLUE, "prf:");
        jpprintf(4,5, (prof<0) ? RED : GREEN, "%.2f", prof);
    }
}

void do_expose() {
    do_update();
}
    
void do_button_release() {
    do_update();
}
